<?php
/**
 * Plugin Name:       Content Query
 * Description:       A collection of block, theme and content querying tools
 * Version:           1.0.0-beta.3
 * Requires at least: 5.9
 * Requires PHP:      8.0
 * Author:            Big Bite
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Update URI:        false
 * Text Domain:       bigbite-content-query
 */

namespace BigBite\Content_Query;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! defined( 'BIGBITE_CONTENT_QUERY_PLUGIN_DIR' ) ) {
	define( 'BIGBITE_CONTENT_QUERY_PLUGIN_DIR', rtrim( plugin_dir_path( __FILE__ ), '/' ) );
}

if ( file_exists( BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/asset-settings.php' ) ) {
	require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/asset-settings.php';
}

require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/class-setup.php';
new Setup( __FILE__ );

if (
	! defined( 'CONTENT_QUERY_DASHBOARD_JS' ) ||
	! defined( 'CONTENT_QUERY_DASHBOARD_CSS' ) ||
	! defined( 'CONTENT_QUERY_VERSION' )
) {
	add_action( 'all_admin_notices', function() {
		printf(
			'<div class="notice notice-error is-dismissible"><p>%s</p></div>',
			esc_html__( 'Content Query asset constants are not defined. You may need to run an asset build.', 'bigbite-content-query' )
		);
	} );

	return;
}

require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/class-helpers.php';
require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/class-rest-api.php';
require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/rest-api/abstract-class-rest-api-base.php';
require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/rest-api/class-rest-api-block-search.php';
require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/rest-api/class-rest-api-post-meta-search.php';
require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/rest-api/class-rest-api-media-search.php';
require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/rest-api/class-rest-api-plugins.php';
require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/rest-api/class-rest-api-posts.php';
require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/rest-api/class-rest-api-themes.php';
require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/class-dashboard.php';
require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/class-block-parser.php';
require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/class-post-meta-parser.php';
require_once BIGBITE_CONTENT_QUERY_PLUGIN_DIR . '/inc/class-type-comparison.php';
new Rest_API();
new Dashboard();
